@@ -1,16 +1,57 @@
 # Set default values for all options
 # USAGE: options_init_default
 options_init_default() {
-	# Try to guess the desired package format based on the host system
+	# Guess most appropriate package format based on current system.
 	local default_package_format
-	## Get system codename.
+	default_package_format=$(options_init_default_package)
+
+	# Using a direct export call here instead of relying on option_update_default
+	# massively improves performances when running a lot of ./play.it calls,
+	# like what is done by the --list-supported-games option.
+	export \
+		PLAYIT_DEFAULT_OPTION_CHECKSUM='md5' \
+		PLAYIT_DEFAULT_OPTION_COMPRESSION='none' \
+		PLAYIT_DEFAULT_OPTION_OUTPUT_DIR="$PWD" \
+		PLAYIT_DEFAULT_OPTION_PACKAGE=$default_package_format \
+		PLAYIT_DEFAULT_OPTION_PREFIX='/usr' \
+		PLAYIT_DEFAULT_OPTION_TMPDIR="${TPMDIR:-/tmp}" \
+		PLAYIT_DEFAULT_OPTION_FREE_SPACE_CHECK=1 \
+		PLAYIT_DEFAULT_OPTION_ICONS=1 \
+		PLAYIT_DEFAULT_OPTION_MTREE=1 \
+		PLAYIT_DEFAULT_OPTION_HELP=0 \
+		PLAYIT_DEFAULT_OPTION_LIST_AVAILABLE_SCRIPTS=0 \
+		PLAYIT_DEFAULT_OPTION_LIST_PACKAGES=0 \
+		PLAYIT_DEFAULT_OPTION_LIST_REQUIREMENTS=0 \
+		PLAYIT_DEFAULT_OPTION_LIST_SUPPORTED_GAMES=0 \
+		PLAYIT_DEFAULT_OPTION_OVERWRITE=0 \
+		PLAYIT_DEFAULT_OPTION_SHOW_GAME_SCRIPT=0 \
+		PLAYIT_DEFAULT_OPTION_VERSION=0
+}
+
+# Guess most appropriate package format based on current system.
+# USAGE: options_init_default_package
+options_init_default_package() {
+	# If a value is already set, return early.
+	if [ -n "${PLAYIT_DEFAULT_OPTION_PACKAGE:-}" ]; then
+		printf '%s' "$PLAYIT_DEFAULT_OPTION_PACKAGE"
+		return 0
+	fi
+
+	# Identify the current system.
 	local host_system
 	if [ -e '/etc/os-release' ]; then
-		host_system=$(grep '^ID=' '/etc/os-release' | cut --delimiter='=' --fields=2)
+		host_system=$(
+			grep --regexp='^ID=' /etc/os-release |
+				cut --delimiter='=' --fields=2 |
+				## This sed call is used to remove enclosing quotes.
+				sed "s/^[\"']//;s/[\"']$//"
+		)
 	elif command -v lsb_release >/dev/null 2>&1; then
 		host_system=$(lsb_release --id --short | tr '[:upper:]' '[:lower:]')
 	fi
-	## Set the most appropriate package type for the current system.
+
+	# Set the most appropriate package type.
+	local default_package_format
 	case "${host_system:-}" in
 		( \
 			'debian' | \
@@ -37,27 +78,8 @@ options_init_default() {
 		;;
 	esac
 
-	# Using a direct export call here instead of relying on option_update_default
-	# massively improves performances when running a lot of ./play.it calls,
-	# like what is done by the --list-supported-games option.
-	export \
-		PLAYIT_DEFAULT_OPTION_CHECKSUM='md5' \
-		PLAYIT_DEFAULT_OPTION_COMPRESSION='none' \
-		PLAYIT_DEFAULT_OPTION_OUTPUT_DIR="$PWD" \
-		PLAYIT_DEFAULT_OPTION_PACKAGE="${default_package_format:-deb}" \
-		PLAYIT_DEFAULT_OPTION_PREFIX='/usr' \
-		PLAYIT_DEFAULT_OPTION_TMPDIR="${TPMDIR:-/tmp}" \
-		PLAYIT_DEFAULT_OPTION_FREE_SPACE_CHECK=1 \
-		PLAYIT_DEFAULT_OPTION_ICONS=1 \
-		PLAYIT_DEFAULT_OPTION_MTREE=1 \
-		PLAYIT_DEFAULT_OPTION_HELP=0 \
-		PLAYIT_DEFAULT_OPTION_LIST_AVAILABLE_SCRIPTS=0 \
-		PLAYIT_DEFAULT_OPTION_LIST_PACKAGES=0 \
-		PLAYIT_DEFAULT_OPTION_LIST_REQUIREMENTS=0 \
-		PLAYIT_DEFAULT_OPTION_LIST_SUPPORTED_GAMES=0 \
-		PLAYIT_DEFAULT_OPTION_OVERWRITE=0 \
-		PLAYIT_DEFAULT_OPTION_SHOW_GAME_SCRIPT=0 \
-		PLAYIT_DEFAULT_OPTION_VERSION=0
+	# Print the default package format, falling back on "deb".
+	printf '%s' "${default_package_format:-deb}"
 }
 
 # Get the name of the variable used to store the value of the given option
