@@ -36,6 +36,10 @@ archive_initialize_required() {
 			export "${archive_identifier}_EXTRACTOR=${archive_extractor}"
 			export "${archive_identifier}_EXTRACTOR_OPTIONS=${archive_extractor_options}"
 			export "${archive_identifier}_TYPE=${archive_type}"
+			## Set archive version string.
+			local archive_version
+			archive_version=$(archive_version "$archive_candidate")
+			export "${archive_identifier}_VERSION=${archive_version}"
 			## Look for extra parts
 			archive_initialize_extra_parts "$archive_candidate"
 			## Update the list of archives that are going to be used
@@ -64,6 +68,25 @@ archive_initialize_optional() {
 		if [ -f "$archive_path" ]; then
 			local archive_name
 			archive_name=$(archive_name "$archive_candidate")
+
+			# Run a MD5 hash comparison, to ensure the current archive is the expected one.
+			local option_checksum archive_hash_expected archive_candidate_hash_computed
+			option_checksum=$(option_value 'checksum')
+			case "$option_checksum" in
+				('md5')
+					archive_hash_expected=$(get_value "${archive_candidate}_MD5")
+					if [ -n "$archive_hash_expected" ]; then
+						## TODO: archive_hash_md5_computed could be used
+						##       if it relied on the file name instead of the archive identifier.
+						info_archive_hash_computation "$archive_name"
+						archive_candidate_hash_computed=$(md5sum "$archive_path" | awk '{print $1}')
+						if [ "$archive_candidate_hash_computed" != "$archive_hash_expected" ]; then
+							continue
+						fi
+					fi
+				;;
+			esac
+
 			export "${archive_identifier}_NAME=${archive_name}"
 			export "${archive_identifier}_PATH=${archive_path}"
 			## Cache the path to the candidate archive, to prevent the need to re-compute it later.
@@ -78,6 +101,10 @@ archive_initialize_optional() {
 			export "${archive_identifier}_EXTRACTOR=${archive_extractor}"
 			export "${archive_identifier}_EXTRACTOR_OPTIONS=${archive_extractor_options}"
 			export "${archive_identifier}_TYPE=${archive_type}"
+			## Set archive version string.
+			local archive_version
+			archive_version=$(archive_version "$archive_candidate")
+			export "${archive_identifier}_VERSION=${archive_version}"
 			## Look for extra parts
 			archive_initialize_extra_parts "$archive_candidate"
 			## Update the list of archives that are going to be used
