@@ -9,18 +9,17 @@ archive_extraction_using_unzip() {
 	local archive_path
 	archive_path=$(archive_path "$archive")
 
-	local extractor_options archive_extraction_return_code
+	local extractor_options
 	extractor_options=$(archive_extractor_options "$archive")
 	if [ -z "$extractor_options" ]; then
 		## unzip -o: overwrite existing files without prompting.
 		extractor_options='-o'
 	fi
-	printf 'unzip %s -d "%s" "%s"\n' "$extractor_options" "$destination_directory" "$archive_path" >> "$log_file"
-	{
-		unzip $extractor_options -d "$destination_directory" "$archive_path" >> "$log_file" 2>&1
-		archive_extraction_return_code=$?
-	} || true
-	if [ $archive_extraction_return_code -ne 0 ]; then
+	if ! {
+		printf 'unzip %s -d "%s" "%s"\n' "$extractor_options" "$destination_directory" "$archive_path"
+		unzip $extractor_options -d "$destination_directory" "$archive_path" 2>&1
+	} >> "$log_file"
+	then
 		error_archive_extraction_failure "$archive"
 		return 1
 	fi
