@@ -81,6 +81,9 @@ content_files() {
 		local game_engine
 		game_engine=$(game_engine)
 		case "$game_engine" in
+			('ags')
+				content_files=$(ags_content_files_default "$content_id")
+			;;
 			('unity3d')
 				content_files=$(unity3d_content_files_default "$content_id")
 			;;
