@@ -269,9 +269,11 @@ content_inclusion() {
 
 	# Return early if the content source path is not set.
 	local content_path
-	## TODO: content_path relies on the package context being set,
-	##       through a call to content_path_default.
-	content_path=$(content_path "$content_id")
+	## content_path relies on the package context being set, through a call to content_path_default.
+	content_path=$(
+		set_current_package "$package"
+		content_path "$content_id"
+	)
 	if [ -z "$content_path" ]; then
 		return 0
 	fi
