@@ -34,7 +34,7 @@ application_icons_list() {
 	local icons_list
 	icons_list=$(context_value "${application}_ICONS_LIST")
 
-	# Fall back on the default value of a single APP_xxx_ICON icon
+	# Fall back on the default value of a single APP_xxx_ICON icon.
 	if [ -z "$icons_list" ]; then
 		local default_icon
 		default_icon=$(context_name "${application}_ICON")
@@ -45,7 +45,7 @@ application_icons_list() {
 		fi
 	fi
 
-	## If no value is set for APP_xxx_ICON, try to guess one from the game engine.
+	# Try to guess a value from the game engine.
 	if [ -z "$icons_list" ]; then
 		local game_engine
 		game_engine=$(game_engine)
@@ -57,10 +57,12 @@ application_icons_list() {
 		esac
 	fi
 
-	## If no value is set for APP_xxx_ICON, try to guess one from the application type.
+	# Try to guess a value from the application type.
 	if [ -z "$icons_list" ]; then
 		local application_type
-		application_type=$(application_type "$application")
+		## This is allowed to fail, as the binary file might not be available yet.
+		application_type=$(application_type "$application" 2>/dev/null) || true
+		## TODO: Mono binaries usually include an icon too.
 		case "$application_type" in
 			('wine')
 				## If no value is explicitly set for the icon of a WINE application,
@@ -70,6 +72,19 @@ application_icons_list() {
 		esac
 	fi
 
+	# Try to guess a value from the binary name.
+	if [ -z "$icons_list" ]; then
+		local application_exe
+		application_exe=$(application_exe "$application")
+		case "$application_exe" in
+			(*'.exe')
+				## This is most probably a WINE or Mono binary,
+				## the game binary is used as a fallback icons source.
+				icons_list="${application}_ICON"
+			;;
+		esac
+	fi
+
 	printf '%s' "$icons_list"
 }
 
@@ -117,7 +132,7 @@ icon_path() {
 	local icon_path
 	icon_path=$(context_value "$icon")
 
-	## If no value is set for the icon path, try to guess one from the game engine.
+	# Try to guess a value from the game engine.
 	if [ -z "$icon_path" ]; then
 		local game_engine
 		game_engine=$(game_engine)
@@ -128,11 +143,12 @@ icon_path() {
 		esac
 	fi
 
-	## If no value is set for the icon path, try to guess one from the application type.
+	# Try to guess a value from the application type.
 	if [ -z "$icon_path" ]; then
 		local application application_type
 		application=$(icon_application "$icon")
-		application_type=$(application_type "$application")
+		## This is allowed to fail, as the binary file might not be available yet.
+		application_type=$(application_type "$application" 2>/dev/null) || true
 		case "$application_type" in
 			('wine')
 				icon_path=$(icon_wine_path "$icon")
@@ -140,6 +156,19 @@ icon_path() {
 		esac
 	fi
 
+	# Try to guess a value from the binary name.
+	if [ -z "$icon_path" ]; then
+		local application_exe
+		application_exe=$(application_exe "$application")
+		case "$application_exe" in
+			(*'.exe')
+				## This is most probably a WINE or Mono binary,
+				## the game binary is used as a fallback icons source.
+				icon_path=$(icon_wine_path "$icon")
+			;;
+		esac
+	fi
+
 	# Check that the path to the icon is not empty
 	if [ -z "$icon_path" ]; then
 		error_icon_path_empty "$icon"
