@@ -11,9 +11,11 @@ icons_inclusion_single_application() {
 	application="$2"
 
 	local application_icons_list
-	## TODO: application_icons_list relies on the context package being set,
-	##       through a late call to application_exe.
-	application_icons_list=$(application_icons_list "$application")
+	## application_icons_list relies on the context package being set, through a late call to application_exe.
+	application_icons_list=$(
+		set_current_package "$package"
+		application_icons_list "$application"
+	)
 	# Throw an error if no icon was found for the given application.
 	if [ -z "$application_icons_list" ]; then
 		## Skip the error if an icons archives is supported, as a non-blocking warning has already been shown.
