@@ -211,13 +211,16 @@ launcher_write_script() {
 			)
 			chmod +x "$application_exe_path"
 
-			# Add dependencies on some system-provided libraries based on the game engine
+			# Add dependencies on some system-provided libraries based on the game engine.
 			local game_engine
 			game_engine=$(game_engine)
 			case "$game_engine" in
 				('unity3d')
 					dependencies_add_native_libraries "$package" 'libSDL2-2.0.so.0'
 				;;
+				('visionaire')
+					dependencies_add_native_libraries "$package" 'libSDL2-2.0.so.0'
+				;;
 			esac
 		;;
 		('renpy')
