@@ -7,18 +7,7 @@ dependencies_list_siblings() {
 	package="$1"
 
 	local dependencies_siblings
-	dependencies_siblings=$(context_value "${package}_DEPENDENCIES_SIBLINGS")
-
-	# Fall back on the default list of dependencies for the current game engine
-	if [ -z "$dependencies_siblings" ]; then
-		local game_engine
-		game_engine=$(game_engine)
-		case "$game_engine" in
-			('visionaire')
-				dependencies_siblings=$(visionaire_package_dependencies_siblings  "$package")
-			;;
-		esac
-	fi
+	dependencies_siblings=$(package_dependencies_siblings "$package")
 
 	# Return early if the current package does not require any sibling package
 	if [ -z "$dependencies_siblings" ]; then
