@@ -120,7 +120,7 @@ mono_exec_line() {
 	application="$1"
 
 	local application_exe application_options
-	application_exe=$(application_exe_escaped "$application")
+	application_exe=$(application_exe "$application")
 	application_options=$(application_options "$application")
 	cat <<- EOF
 	mono "${application_exe}" $application_options "\$@"
