@@ -171,7 +171,7 @@ native_launcher_run() {
 # USAGE: native_launcher_binary_copy
 native_launcher_binary_copy() {
 	local application_exe exe_destination
-	application_exe=$(application_exe_escaped "$application")
+	application_exe=$(application_exe "$application")
 	exe_destination="\${PATH_PREFIX}/${application_exe}"
 
 	cat <<- 'EOF'
@@ -199,7 +199,7 @@ native_exec_line() {
 	application="$1"
 
 	local application_exe application_options
-	application_exe=$(application_exe_escaped "$application")
+	application_exe=$(application_exe "$application")
 	application_options=$(application_options "$application")
 	cat <<- EOF
 	"./${application_exe}" $application_options "\$@"
