@@ -14,8 +14,7 @@ renpy_launcher() {
 			launcher_init_paths "$application"
 
 			# Generate the game prefix
-			prefix_generate_links_farm
-			launcher_prefix_symlinks_build
+			prefix_symlinks_generate
 
 			# Set up the paths diversion to persistent storage
 			persistent_storage_initialization
