@@ -12,7 +12,7 @@ error_application_scummid_invalid() {
 			message='Lʼid ScummVM fourni pour lʼapplication %s ne semble pas correct : "%s"\n'
 			message="$message"'Une liste de valeurs acceptées peut se trouver sur le site Web de ScummVM : \n%s\n'
 		;;
-		('en')
+		('en'|*)
 			message='The ScummVM id provided for application %s does not seem correct: "%s"\n'
 			message="$message"'A list of valid values can be found on ScummVM website: \n%s\n'
 		;;
