@@ -1,3 +1,26 @@
+# List the WINE .reg scripts that should be executed on WINEPREFIX initialisation
+# USAGE: wine_regedit_init_list
+wine_regedit_init_list() {
+	local scripts_list
+
+	local wine_registry_script_content
+	wine_registry_script_content=$(wine_registry_script_content)
+	if [ -n "$wine_registry_script_content" ]; then
+		scripts_list='registry-scripts/init.reg'
+	fi
+
+	# Check for a legacy list of .reg scripts to load on WINEPREFIX initialisation,
+	# set through the deprecated variable APP_REGEDIT
+	local legacy_scripts_list
+	legacy_scripts_list=$(legacy_registry_scripts_list)
+	if [ -n "$legacy_scripts_list" ]; then
+		scripts_list="${scripts_list:-}
+		$legacy_scripts_list"
+	fi
+
+	printf '%s' "${scripts_list:-}" | list_clean
+}
+
 # WINE launcher - Set environment for registry keys persistent storage
 # USAGE: wine_launcher_regedit_environment
 wine_launcher_regedit_environment() {
@@ -26,19 +49,23 @@ wine_launcher_regedit_environment() {
 	EOF
 }
 
-# WINE launcher - Load registry keys during prefix initialization
+# Load .reg scripts during WINEPREFIX initialisation
 # USAGE: regedit_initial
 regedit_initial() {
-	# Return early if there is no key to load during prefix initilization
-	if [ -z "${APP_REGEDIT:-}" ]; then
+	local scripts_list
+	scripts_list=$(wine_regedit_init_list)
+
+	# Return early if there is no script to load during prefix initilisation
+	if [ -z "$scripts_list" ]; then
 		return 0
 	fi
 
 	local game_id
 	game_id=$(game_id)
+	## TODO: env --chdir could be used instead of cd in a subshell.
 	cat <<- EOF
 	    ## Load registry scripts
-	    registry_scripts='$APP_REGEDIT'
+	    registry_scripts='$scripts_list'
 	    (
 	        cd "\${WINEPREFIX}/drive_c/${game_id}"
 	EOF
@@ -76,6 +103,7 @@ wine_launcher_regedit_store() {
 		return 0
 	fi
 
+	## TODO: env --chdir could be used instead of cd in a subshell.
 	cat <<- 'EOF'
 	# Store registry keys in a persistent path
 
@@ -111,6 +139,7 @@ wine_launcher_regedit_load() {
 		return 0
 	fi
 
+	## TODO: env --chdir could be used instead of cd in a subshell.
 	cat <<- 'EOF'
 	# Load registry keys from persistent dumps
 
