@@ -55,16 +55,27 @@ wine_launcher_wineprefix_environment() {
 	EOF
 
 	# Compute WINE prefix architecture
-	local package package_architecture wine_architecture
-	package=$(current_package)
-	package_architecture=$(package_architecture "$package")
-	case "$package_architecture" in
-		('32')
-			wine_architecture='win32'
-		;;
-		('64')
+	local option_package wine_architecture
+	option_package=$(option_value 'package')
+	case "$option_package" in
+		('arch')
+			## Arch Linux WINE is built in wow64 mode,
+			## in that mode win32 prefixes can not be created.
 			wine_architecture='win64'
 		;;
+		(*)
+			local package package_architecture
+			package=$(current_package)
+			package_architecture=$(package_architecture "$package")
+			case "$package_architecture" in
+				('32')
+					wine_architecture='win32'
+				;;
+				('64')
+					wine_architecture='win64'
+				;;
+			esac
+		;;
 	esac
 
 	# Set variables used for WINE prefix
