@@ -98,16 +98,8 @@ unity3d_content_files_default() {
 	local unity3d_name
 	unity3d_name=$(unity3d_name)
 
-	## FIXME: This snippet used to fetch the tupe of the first application
-	##        is used in multiple places under src/55_engine-variant_*
-	##        A dedicated function, maybe with a cached value, should be provided.
-	local applications_list application application_type
-	applications_list=$(applications_list)
-	if [ -z "$applications_list" ]; then
-		error_applications_list_empty
-	fi
-	application=$(printf '%s' "$applications_list" | head --lines=1)
-	application_type=$(application_type "$application")
+	local application_type
+	application_type=$(application_default_type)
 
 	local content_files
 	case "$content_id" in
