@@ -13,16 +13,8 @@ unrealengine4_dependencies_list_gstreamer_decoders_default() {
 		return 0
 	fi
 
-	## FIXME: This snippet used to fetch the tupe of the first application
-	##        is used in multiple places under src/55_engine-variant_*
-	##        A dedicated function, maybe with a cached value, should be provided.
-	local applications_list application application_type
-	applications_list=$(applications_list)
-	if [ -z "$applications_list" ]; then
-		error_applications_list_empty
-	fi
-	application=$(printf '%s' "$applications_list" | head --lines=1)
-	application_type=$(application_type "$application")
+	local application_type
+	application_type=$(application_default_type)
 
 	local gstreamer_decoders
 	case "$application_type" in
