@@ -71,7 +71,10 @@ archlinux_dependencies_gstreamer_single_format() {
 			package_names='
 			gst-plugins-good'
 		;;
-		('audio/x-wma, wmaversion=(int)1')
+		( \
+			'audio/x-wma' | \
+			'audio/x-wma, wmaversion=(int)1' \
+		)
 			package_names='
 			gst-libav'
 		;;
@@ -95,7 +98,10 @@ archlinux_dependencies_gstreamer_single_format() {
 			gst-plugins-good
 			gst-libav'
 		;;
-		('video/x-wmv, wmvversion=(int)1')
+		( \
+			'video/x-wmv' | \
+			'video/x-wmv, wmvversion=(int)1' \
+		)
 			package_names='
 			gst-libav'
 		;;
@@ -142,7 +148,10 @@ archlinux_dependencies_gstreamer_single_format_32bit() {
 			package_names='
 			lib32-gst-plugins-good'
 		;;
-		('audio/x-wma, wmaversion=(int)1')
+		( \
+			'audio/x-wma' | \
+			'audio/x-wma, wmaversion=(int)1' \
+		)
 			package_names='
 			lib32-gst-libav'
 		;;
@@ -166,7 +175,10 @@ archlinux_dependencies_gstreamer_single_format_32bit() {
 			lib32-gst-plugins-good
 			lib32-gst-libav'
 		;;
-		('video/x-wmv, wmvversion=(int)1')
+		( \
+			'video/x-wmv' | \
+			'video/x-wmv, wmvversion=(int)1' \
+		)
 			package_names='
 			lib32-gst-libav'
 		;;
