@@ -155,7 +155,7 @@ debian_package_build_single() {
 			dpkg_options="${dpkg_options:-} -Zgzip"
 		;;
 		('size')
-			if [ "${PLAYIT_DEBIAN_OLD_DEB_FORMAT:-0}" -eq 1 ]; then
+			if [ "$package_size" -gt 9700000 ]; then
 				## Old .deb format 0.939000 is not compatible with xz compression.
 				dpkg_options="${dpkg_options:-} -Zgzip"
 			else
@@ -163,7 +163,7 @@ debian_package_build_single() {
 			fi
 		;;
 		('auto')
-			if [ "${PLAYIT_DEBIAN_OLD_DEB_FORMAT:-0}" -eq 1 ]; then
+			if [ "$package_size" -gt 9700000 ]; then
 				## Old .deb format 0.939000 is not compatible with xz compression.
 				dpkg_options="${dpkg_options:-} -Zgzip"
 			fi
