@@ -97,6 +97,10 @@ debian_dependencies_single_command() {
 			package_names='
 			openmw-launcher'
 		;;
+		('pidwait')
+			package_names='
+			procps:amd64 | procps'
+		;;
 		('pulseaudio')
 			package_names='
 			pulseaudio:amd64 | pulseaudio'
