@@ -60,7 +60,10 @@ debian_dependencies_gstreamer_single_format() {
 			package_names='
 			gstreamer1.0-plugins-good'
 		;;
-		('audio/x-wma, wmaversion=(int)1')
+		( \
+			'audio/x-wma' | \
+			'audio/x-wma, wmaversion=(int)1' \
+		)
 			package_names='
 			gstreamer1.0-libav'
 		;;
@@ -84,7 +87,10 @@ debian_dependencies_gstreamer_single_format() {
 			gstreamer1.0-plugins-good
 			gstreamer1.0-libav'
 		;;
-		('video/x-wmv, wmvversion=(int)1')
+		( \
+			'video/x-wmv' | \
+			'video/x-wmv, wmvversion=(int)1' \
+		)
 			package_names='
 			gstreamer1.0-libav'
 		;;
