@@ -364,7 +364,7 @@ dependency_package_providing_library_deb() {
 			'libQt5Core.so.5' | \
 			'libQt5Gui.so.5' \
 		)
-			package_name='libqt5core5'
+			package_name='libqt5core5a'
 		;;
 		('libQt5Widgets.so.5')
 			package_name='libqt5widgets5'
