@@ -83,6 +83,10 @@ gentoo_dependencies_single_command() {
 			package_names='
 			games-engines/openmw'
 		;;
+		('pidwait')
+			package_names='
+			sys-process/procps'
+		;;
 		('pulseaudio')
 			package_names='
 			media-sound/pulseaudio'
