@@ -71,7 +71,10 @@ gentoo_dependencies_gstreamer_single_format() {
 			package_names='
 			media-libs/gst-plugins-good'
 		;;
-		('audio/x-wma, wmaversion=(int)1')
+		( \
+			'audio/x-wma' | \
+			'audio/x-wma, wmaversion=(int)1' \
+		)
 			package_names='
 			media-plugins/gst-plugins-libav'
 		;;
@@ -95,7 +98,10 @@ gentoo_dependencies_gstreamer_single_format() {
 			media-libs/gst-plugins-good
 			media-plugins/gst-plugins-libav'
 		;;
-		('video/x-wmv, wmvversion=(int)1')
+		( \
+			'video/x-wmv' | \
+			'video/x-wmv, wmvversion=(int)1' \
+		)
 			package_names='
 			media-plugins/gst-plugins-libav'
 		;;
@@ -142,7 +148,10 @@ gentoo_dependencies_gstreamer_single_format_32bit() {
 			package_names='
 			media-libs/gst-plugins-good[abi_x86_32]'
 		;;
-		('audio/x-wma, wmaversion=(int)1')
+		( \
+			'audio/x-wma' | \
+			'audio/x-wma, wmaversion=(int)1' \
+		)
 			package_names='
 			media-plugins/gst-plugins-libav[abi_x86_32]'
 		;;
@@ -166,7 +175,10 @@ gentoo_dependencies_gstreamer_single_format_32bit() {
 			media-libs/gst-plugins-good[abi_x86_32]
 			media-plugins/gst-plugins-libav[abi_x86_32]'
 		;;
-		('video/x-wmv, wmvversion=(int)1')
+		( \
+			'video/x-wmv' | \
+			'video/x-wmv, wmvversion=(int)1' \
+		)
 			package_names='
 			media-plugins/gst-plugins-libav[abi_x86_32]'
 		;;
