@@ -386,6 +386,15 @@ dependency_package_providing_library_gentoo() {
 		('libpulse-simple.so.0')
 			package_name='media-sound/pulseaudio'
 		;;
+		('libQt5Core.so.5')
+			package_name='dev-qt/qtcore'
+		;;
+		('libQt5Gui.so.5')
+			package_name='dev-qt/qtgui'
+		;;
+		('libQt5Widgets.so.5')
+			package_name='dev-qt/qtwidgets'
+		;;
 		('libresolv.so.2')
 			package_name='sys-libs/glibc'
 		;;
@@ -960,6 +969,15 @@ dependency_package_providing_library_gentoo32() {
 		('libpulse-simple.so.0')
 			package_name='media-sound/pulseaudio[abi_x86_32]'
 		;;
+		('libQt5Core.so.5')
+			package_name='dev-qt/qtcore[abi_x86_32]'
+		;;
+		('libQt5Gui.so.5')
+			package_name='dev-qt/qtgui[abi_x86_32]'
+		;;
+		('libQt5Widgets.so.5')
+			package_name='dev-qt/qtwidgets[abi_x86_32]'
+		;;
 		('libresolv.so.2')
 			package_name='sys-libs/glibc amd64? ( sys-libs/glibc[multilib] )'
 		;;
